# Generated by Django 2.1 on 2019-01-11 05:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('knox', '0006_auto_20160818_0932'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoken',
            old_name='expires',
            new_name='expiry',
        ),
    ]
